ReadStatus

Enum ReadStatus 

pub enum ReadStatus {
    Done,
    NeedMoreBytes,
    LeftoverBytes(u16),
}
Possible responses to responding to a read request

Variants



Done

Transaction Complete; master completed reading all provided bytes.



NeedMoreBytes

Transaction Incomplete; master is trying to read more bytes than were provided.



LeftoverBytes(u16)

Transaction Complete, but master stopped reading before all bytes were consumed.